Test your self always! With ThePocketTrainer, you can quiz your self endlessly for any number of test on any number of subjects. As the Library grows, you will see new features like flashcards and Gamification. Finally the next app will be an Audio Player With Quiz questions and answers over music:) 

you will need to install Pandas and create a CSV file called "questions.csv" in your Python folder that looks like

    QUESTIONS, ANSWERS, LINKS
    question1, answer1, link1
    question2, answer2, link2

The App will let you show the first Question, and show the Answer, finally showing the link to documentation.  

To run, create a main.py file and add:

    from cert_quiz_app import GUI

    app = GUI()
    app.run()

run the command "python3 main.py"